@@ -196,6 +196,64 @@ Billiard_multiprocessing_address_of_buffer(PyObject *self, PyObject *obj)
                          PyLong_FromVoidPtr(buffer), buffer_len);
 }
 
+#if !defined(MS_WINDOWS)
+
+static PyObject *
+Billiard_read(PyObject *self, PyObject *args)
+{
+    int fd;
+    Py_buffer view;
+    Py_ssize_t buflen, recvlen = 0;
+
+    char *buf = NULL;
+
+    Py_ssize_t n = 0;
+
+    if (!PyArg_ParseTuple(args, "iw*|n", &fd, &view, &recvlen))
+        return NULL;
+    buflen = view.len;
+    buf = view.buf;
+
+    if (recvlen < 0) {
+        PyBuffer_Release(&view);
+        PyErr_SetString(PyExc_ValueError, "negative len for read");
+        return NULL;
+    }
+
+    if (recvlen == 0) {
+        recvlen = buflen;
+    }
+
+    if (buflen < recvlen) {
+        PyBuffer_Release(&view);
+        PyErr_SetString(PyExc_ValueError,
+            "Buffer too small for requested bytes");
+        return NULL;
+
+    }
+
+    if (buflen < 0 || buflen == 0) {
+        errno = EINVAL;
+        goto bail;
+    }
+    // Requires Python 2.7
+    //if (!_PyVerify_fd(fd)) goto bail;
+
+    Py_BEGIN_ALLOW_THREADS
+    n = read(fd, buf, recvlen);
+    Py_END_ALLOW_THREADS
+    if (n < 0) goto bail;
+    PyBuffer_Release(&view);
+    return PyInt_FromSsize_t(n);
+
+bail:
+    PyBuffer_Release(&view);
+    return PyErr_SetFromErrno(PyExc_OSError);
+}
+
+# endif /* !MS_WINDOWS */
+
+
 
 /*
  * Function table
@@ -203,17 +261,22 @@ Billiard_multiprocessing_address_of_buffer(PyObject *self, PyObject *obj)
 
 static PyMethodDef Billiard_module_methods[] = {
     {"address_of_buffer", Billiard_multiprocessing_address_of_buffer, METH_O,
-     "address_of_buffer(obj) -> int\n"
+     "address_of_buffer(obj) -> int\n\n"
      "Return address of obj assuming obj supports buffer inteface"},
 #if HAVE_FD_TRANSFER
     {"sendfd", Billiard_multiprocessing_sendfd, METH_VARARGS,
-     "sendfd(sockfd, fd) -> None\n"
+     "sendfd(sockfd, fd) -> None\n\n"
      "Send file descriptor given by fd over the unix domain socket\n"
      "whose file decriptor is sockfd"},
     {"recvfd", Billiard_multiprocessing_recvfd, METH_VARARGS,
-     "recvfd(sockfd) -> fd\n"
+     "recvfd(sockfd) -> fd\n\n"
      "Receive a file descriptor over a unix domain socket\n"
      "whose file decriptor is sockfd"},
+#endif
+#if !defined(MS_WINDOWS)
+    {"read", Billiard_read, METH_VARARGS,
+     "read(fd, buffer) -> bytes\n\n"
+     "Read from file descriptor into buffer."},
 #endif
     {NULL}
 };
