@@ -9,8 +9,6 @@
 #
 from __future__ import absolute_import
 
-__all__ = ['BaseManager', 'SyncManager', 'BaseProxy', 'Token']
-
 #
 # Imports
 #
@@ -28,6 +26,8 @@ from .forking import exit, Popen
 from .reduction import ForkingPickler
 from .util import Finalize, error, info
 
+__all__ = ['BaseManager', 'SyncManager', 'BaseProxy', 'Token']
+
 #
 # Register some things for pickling
 #
@@ -380,9 +380,9 @@ class Server(object):
             if method_to_typeid is not None:
                 assert type(method_to_typeid) is dict
                 exposed = list(exposed) + list(method_to_typeid)
-
-            ident = '%x' % id(obj)  # convert to string because xmlrpclib
-                                    # only has 32 bit signed integers
+            # convert to string because xmlrpclib
+            # only has 32 bit signed integers
+            ident = '%x' % id(obj)
             util.debug('%r callable returned object with id %r', typeid, ident)
 
             self.id_to_obj[ident] = (obj, set(exposed), method_to_typeid)
