@@ -8,8 +8,6 @@
 #
 from __future__ import absolute_import
 
-__all__ = ['Process', 'current_process', 'active_children']
-
 #
 # Imports
 #
@@ -36,6 +34,8 @@ try:
 except OSError:
     ORIGINAL_DIR = None
 
+__all__ = ['Process', 'current_process', 'active_children']
+
 #
 # Public functions
 #
@@ -129,8 +129,6 @@ class Process(object):
         assert self._popen is None, 'cannot start a process twice'
         assert self._parent_pid == os.getpid(), \
             'can only start a process object created by current process'
-        assert not _current_process._daemonic, \
-            'daemonic processes are not allowed to have children'
         _cleanup()
         if self._Popen is not None:
             Popen = self._Popen
@@ -168,6 +166,11 @@ class Process(object):
         self._popen.poll()
         return self._popen.returncode is None
 
+    def _is_alive(self):
+        if self._popen is None:
+            return False
+        return self._popen.poll() is None
+
     def _get_name(self):
         return self._name
 
