@@ -2,11 +2,12 @@ from __future__ import absolute_import
 
 import os
 import signal
+import sys
 
 from contextlib import contextmanager
-from mock import call, patch, Mock
 from time import time
 
+from nose import SkipTest
 from billiard.common import (
     _shutdown_cleanup,
     reset_signals,
@@ -15,6 +16,11 @@ from billiard.common import (
 
 from .utils import Case
 
+try:
+    from unittest.mock import Mock, call, patch
+except ImportError:
+    from mock import Mock, call, patch  # noqa
+
 
 def signo(name):
     return getattr(signal, name)
@@ -33,6 +39,10 @@ def termsigs(default, full):
 
 class test_reset_signals(Case):
 
+    def setUp(self):
+        if sys.platform == 'win32':
+            raise SkipTest('win32: skip')
+
     def test_shutdown_handler(self):
         with patch('sys.exit') as exit:
             _shutdown_cleanup(15, Mock())
